Index: config/kfreebsd-amd64.cfg
===================================================================
--- config/kfreebsd-amd64.cfg	(revision 64650)
+++ config/kfreebsd-amd64.cfg	(working copy)
@@ -1,4 +1,4 @@
-MEDIUM_SUPPORTED = cdrom netboot
+MEDIUM_SUPPORTED = cdrom netboot netboot-gtk
 MEDIUM_SUPPORTED_EXTRA = monolithic
 
 # The version of the kernel to use.
Index: config/kfreebsd-amd64/cdrom.cfg
===================================================================
--- config/kfreebsd-amd64/cdrom.cfg	(revision 64650)
+++ config/kfreebsd-amd64/cdrom.cfg	(working copy)
@@ -6,3 +6,8 @@
 MANIFEST-KERNEL = "kernel for use with mkisofs to build a CD"
 MANIFEST-INITRD = "initrd for use with mkisofs to build a CD"
 MANIFEST-DEBIAN_CD_INFO = "mkisofs config files for CD"
+
+# Add the gtk images.
+INITRD_GTK = dest/cdrom/gtk/initrd.gz
+
+EXTRATARGETS = build_cdrom_gtk
Index: config/kfreebsd-amd64/netboot-gtk.cfg
===================================================================
--- config/kfreebsd-amd64/netboot-gtk.cfg	(revision 0)
+++ config/kfreebsd-amd64/netboot-gtk.cfg	(revision 0)
@@ -0,0 +1,19 @@
+MEDIA_TYPE = netboot image
+
+NETBOOT_DIR_TARGETS = $(TEMP_INITRD) $(TEMP_KERNEL)
+NETBOOT_DIR_LINKS = grub2pxe
+
+TYPE = netboot/gtk
+
+TARGET = $(NETBOOT_DIR) $(NETBOOT_TAR) $(MINIISO)
+EXTRANAME = netboot/gtk/
+
+MANIFEST-NETBOOT_DIR = "PXE boot directory for tftp server (graphical installer)"
+MANIFEST-NETBOOT_TAR = "tarball of PXE boot directory (graphical installer)"
+MANIFEST-MINIISO = "not so tiny CD image that boots the graphical netboot installer"
+
+KEEP_GI_LANGS = 1
+
+# All images that include cdebconf should include symbols needed by these
+# plugins.
+EXTRAUDEBS += cdebconf-gtk-entropy
Index: pkg-lists/netboot/gtk/kfreebsd-amd64.cfg
===================================================================
--- pkg-lists/netboot/gtk/kfreebsd-amd64.cfg	(revision 0)
+++ pkg-lists/netboot/gtk/kfreebsd-amd64.cfg	(revision 0)
@@ -0,0 +1,14 @@
+# Disable Linux-specific drivers (see gtk-common)
+xserver-xorg-input-evdev-udeb -
+xserver-xorg-video-fbdev-udeb -
+
+# Enable generic drivers
+xserver-xorg-input-kbd-udeb
+xserver-xorg-input-mouse-udeb
+xserver-xorg-video-vesa-udeb
+
+# Revert switch from kbd-chooser to console-setup (see gtk-common)
+console-setup-udeb -
+console-setup-pc-ekmap -
+kbd-chooser
+console-keymaps-at
Index: Makefile
===================================================================
--- Makefile	(revision 64651)
+++ Makefile	(working copy)
@@ -126,8 +126,17 @@
   (cd $(TREE) && find . | cpio --quiet -o -H newc) > 
 endef
 
+# Limit on mfsroot size. It is determined by NKPT (in <machine/pmap.h).
+# On amd64, it can be increased by increasing this variable.  On i386,
+# this is a hard limit due to constraints of 4 GiB VM space.
+ifeq ($(DEB_HOST_ARCH),kfreebsd-i386)
+MFSROOT_LIMIT := 42m
+else ifeq ($(DEB_HOST_ARCH),kfreebsd-amd64)
+MFSROOT_LIMIT := 64m
+endif
+
 define mkfs.ufs1
-  sh -c 'makefs -t ffs -s 42m -f 3000 -o minfree=0,version=1 $$0 ${TREE}'
+  sh -c 'makefs -t ffs -s $(MFSROOT_LIMIT) -f 3000 -o minfree=0,version=1 $$0 ${TREE}'
 endef
 
 define e2fsck
